Module spawner

Module spawner 

Per-command shell-wrapping spawn + Stdio::piped() stdin (FR-001).

Functions

spawn_one
Spawn one command via the platform shell with stdin piped. On Unix: /bin/sh -c '<cmd>'. On Windows: cmd /C "<cmd>".
spawn_one_piped_stdout
Spawn one command via the platform shell with piped stdout (for --capture mode).