Per-command shell-wrapping spawn + Stdio::piped() stdin (FR-001).
Functions
- spawn_
one - Spawn one command via the platform shell with stdin piped.
On Unix:
/bin/sh -c '<cmd>'. On Windows:cmd /C "<cmd>". - spawn_
one_ piped_ stdout - Spawn one command via the platform shell with piped stdout (for
--capturemode).